#
# spec file for package enblend-enfuse
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _build_doc 0

Name:           enblend-enfuse
Url:            http://enblend.sourceforge.net/
Summary:        Tool for Composing Images
License:        GPL-2.0+
Group:          Productivity/Graphics/Other
Version:        4.1.3
Release:        4.28
Source:         http://sourceforge.net/projects/enblend/files/%{name}/%{name}-4.1/%{name}-%{version}.tar.gz
Patch1:         use-default-gcc-inlining.diff
BuildRequires:  OpenEXR-devel
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  gsl-devel
BuildRequires:  help2man
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel >= 2.5
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libxml2-tools
#BuildRequires:  mathml-dtd
BuildRequires:  perl-TimeDate
BuildRequires:  plotutils-devel
BuildRequires:  sed
BuildRequires:  vigra-devel
%if %{_build_doc}
BuildRequires:  ImageMagick
BuildRequires:  gnuplot
BuildRequires:  texinfo
BuildRequires:  tidy
BuildRequires:  transfig
#BuildRequires:  xhtml-dtd
%if 0%{?suse_version} > 1220
BuildRequires:  help2man
%endif
%endif
Provides:       enblend = %{version}
Provides:       enfuse = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %install_info_prereq

%description
Enblend is a tool for compositing images using a Burt & Adelson
multiresolution spline. This technique tries to make the seams between
the input images invisible. The basic idea is that image features
should be blended across a transition zone, proportional in size to the
spatial frequency of the features. For example, objects like trees and
window panes have rapid changes in color. By blending these features in
a narrow zone, you cannot see the seam because the eye already expects
to see color changes at the edge of these features. Clouds and sky are
the opposite. These features must be blended across a wide transition
zone because any sudden change in color is immediately noticeable.


%prep
%setup -q
%patch1

%build
ACLOCAL="aclocal -I m4" autoreconf -f -i
# The gcc 4.5 performs too poor compiling this package with -O2, can take days.
# gcc-4.7 still needs too much resources to build on x86_64 with -O2 and OBS virtual engine crashes after a hour.
export CFLAGS="$RPM_OPT_FLAGS -Os"
export CXXFLAGS="$RPM_OPT_FLAGS -Os"
%configure
# NO, do not use this here, it breaks the build due to lack of resources
#make %{?_smp_mflags}
make
# FIXME: We need xhtml-math-svg.dtd https://bugzilla.novell.com/show_bug.cgi?id=799075
#make %{?_smp_mflags} xhtml

%install
%makeinstall
#make install-xhtml DESTDIR=%{buildroot}

%clean
rm -rf %{buildroot}

%if %{_build_doc}
%post
%install_info --info-dir=%{_infodir} %{_infodir}/enblend.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/enfuse.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/enfuse-focus-stacking.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/enblend.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/enfuse.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/enfuse-focus-stacking.info.gz
%endif

%files
%defattr(-,root,root)
# ChangeLog does not contain anything useful
%doc AUTHORS COPYING NEWS README
%if %{_build_doc}
%doc doc/*.pdf
%doc %{_infodir}/*.*
%endif
%{_bindir}/*
%doc %{_mandir}/*/*.*

%changelog
* Wed Feb 11 2015 dimstar@opensuse.org
- Introduce _build_doc defines (currently set to 0): Allow to
  easily enable/disable the building of the documentation (incl.
  the reevant BuildRequires and file sections). Currently disabled,
  as enblend fails with texinfo 5.1; upstream is aware but there
  are multiple ways the texi files are broken (mainly using invalid
  characters for defintions).
* Sun Nov 16 2014 meissner@suse.com
- no more upstream tarball signatures, no need for gpg offline
* Wed Apr 23 2014 fcrozat@suse.com
- Update to patchlevel 3 of version 4.1:
  + Bug Fixes:
    [Enblend only] Fix problem of multiple, almost-identical
    seamlines that produce inexplicable black areas in the output
    panorama.
  + LCMS 2.5 is now required to build.
* Sun Dec 29 2013 adrian@suse.de
- update to patchlevel 2 of version 4.1:
  [Enblend and Enfuse] Fix a bug in the highlight-recovery that caused
  Enfuse to bail out with the uncaught exception
    "Minimizer1D::set_bracket: minimum not bracketed".
  This addresses LaunchPad Bug #1214004.
  [Enfuse] Clean up seemingly random, bright-colored pixels that
  sometimes show up when fusing images with high contrast and "large"
  color profiles.
  [Enblend only] Fix a race condition in the seam-line optimizer that
  can cause wrongly placed seams.
  [Enblend and Enfuse] Use a per-thread storage of all OpenMP
  Vigra-functors.  This avoids data races.
  [Enblend and Enfuse] The Boost implementation of the `Mersenne
  Twister' random number generator caused segmentation faults when
  used in the OpenMP-enabled versions of Enblend and Enfuse.  The new
  implementation is based on the GNU Scientific Library (GSL), which
  plays nicely with concurrent accesses.
  [Enblend only] Correct a mistake that causes overlapping images with
  multiple seams to be blended incorrectly.
  [Enblend only] Require the OpenGL extension
  `GL_ARB_texture_rectangle' for the `--gpu' option to work.  This
  does away with a pesky warning of OpenGL drivers that do support
  this extension and avoids crashes with drivers that don't.
  The GPU performance improvement of Enblend via `--gpu' now is only
  available with drivers that feature `GL_ARB_texture_rectangle'
  (among many other required OpenGL extensions).
  The OpenGL warning about odd texture sizes is unaffected by this
  change.
  [Enblend and Enfuse] Fix a longstanding quirk, which allowed to load
  masks that were unsuitable for processing.
- no more signed tar balls, droping gpg verification :/
- modified patches:
  * use-default-gcc-inlining.diff
* Mon May 27 2013 mmeister@suse.com
- Added BuildRequire help2man to fix build with new automake
* Thu Jan 17 2013 sbrabec@suse.cz
- Update to version 4.1 (bnc#800803):
  * All deprecated options since version 4.0 have been removed.
  * New primary seam-line generator.
  * Default to perceptual model of the difference image.
  * Parallelize CIECAM02 color conversion.
  * Enblend and Enfuse integrate seamlessly in color-managed
    workflow.
  * Require LittleCMS Version 2.x Unbounded CMM feature.
  * Option to assign different profiles to profile-free input images.
  * New gray-scale projector called "anti-value".
  * Enblend and Enfuse stop after saving all generated masks to
    files, if option "--save-masks" is given, but option "--output"
    is not.
  * Enblend and Enfuse can write output JPEG files with arithmetic
    JPEG compression and TIFF files with JPEG compression.
  * Enblend and Enfuse warn on images that alternate between with
    color profile and without.
  * Several new Commandline options: "--primary-seam-generator",
    "--image-difference", "--ciecam" (for -c) and --no-ciecam",
    "--fallback-profile=PROFILE", "--exposure-cutoff",
    "--load-masks", "--layer-selector", "--levels=auto".
  * Deprecated: "--smooth-difference", user-(re)sizable image-cache.
  * External Vigra version 1.8 or later is required.
  * Enblend no longer relies on libXMI.
- Verify GPG signature.
* Wed Oct 24 2012 gankov@opensuse.org
- workaround vigra bug where arithmetic coded JPEG is always
  created with libjpeg-turbo #bnc786566
* Wed Oct  3 2012 pgajdos@suse.com
- really build also with older libpng14
* Tue Sep  4 2012 pgajdos@suse.com
- build also with libpng15
  * libpng15.patch
* Tue Jan 10 2012 crrodriguez@opensuse.org
- libjpeg-devel was missing in buildrequires.
* Tue Dec  6 2011 cfarrell@suse.com
- license update: GPL-2.0+
  No reason to believe the VIGRA license is used in aggregation. Use SPDX
  syntax
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Sep 21 2011 adrian@suse.de
- drop %%_smp_mflags again, it takes too much resources
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Add missing make call
- Use %%_smp_mflags for parallel build
* Fri Sep 16 2011 adrian@suse.com
- use original source
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Wed May 19 2010 adrian@suse.de
- compile with -Os on openSUSE 11.3 x86_64, because gcc 4.5
  is way slower and needs more resources (build time can reach a day)
* Thu Apr  8 2010 pgajdos@suse.cz
- build with libpng14
* Tue Mar 30 2010 adrian@suse.de
- update to version 4.0:
  * too many changes for this changelog, have a look at the NEWS file
* Thu Jan 15 2009 sbrabec@suse.cz
- Changed BuildRequires: plotutils -> plotutils-devel.
* Wed Sep 10 2008 sbrabec@suse.cz
- Updated to version 3.2:
  * Project renamed to enblend-enfuse.
  * Fixed a bug in the NotifyingDirectionSelector's assignment
    operator.
  * Minor fixes.
  * Documentation fixes.
* Tue Jul 15 2008 sbrabec@suse.cz
- Updated to the current CVS snapshot:
  * enfuse code enhancements
  * vigra code cleanup
* Wed Apr 23 2008 sbrabec@suse.cz
- Enblend identifies itself as 3.1, set version tag to 3.0.99.x.
* Tue Apr 22 2008 sbrabec@suse.cz
- Updated to the current CVS snapshot:
  * Enfuse program for automatic multi-level exposure blending
  * Support for PNG and OpenEXR input files.
  * Correctly interpret alpha channel of float (HDR) images.
  * Output to jpg possible (8 bit only).
  * Compression can be specified with the new --compression option
* Wed Dec 12 2007 nadvornik@suse.cz
- fixed includes for gcc 4.3
* Tue Jul 24 2007 sbrabec@suse.cz
- Better work-around for internal compiler error (#290663).
* Tue Jul 10 2007 sbrabec@suse.cz
- Updated to version 3.0:
  * New, faster image processing algorithms for computing Gaussian
    and Laplacian pyramids.
  * Optional optimization of seam line placement to try to avoid
    mismatches and parallax errors in the image overlap region.
  * Masks can now be saved and loaded from files.
  * Checkpointing of partial results is now optional.
  * Optional blending using the CIECAM02 color appearance model.
  * Optional use of the graphics processor to speed up certain
    computations.
* Wed Apr 12 2006 sbrabec@suse.cz
- Removed non distributable PhaseCorrelation.h (#74354).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  2 2006 sbrabec@suse.cz
- Updated to version 2.5.
* Mon Apr 18 2005 mcihar@suse.cz
- update to 2.3
* Wed Mar 23 2005 mcihar@suse.cz
- remove non distributable header file (bug #74354)
* Mon Feb  7 2005 mcihar@suse.cz
- update to 2.2
* Tue Dec 21 2004 mcihar@suse.cz
- update to 2.1
* Fri Jul 30 2004 mcihar@suse.cz
- initial packaging
